=== modified file 'cronscripts/buildd-queue-builder.py'
--- cronscripts/buildd-queue-builder.py	2007-11-22 19:00:41 +0000
+++ cronscripts/buildd-queue-builder.py	2007-11-23 16:44:08 +0000
@@ -39,8 +39,8 @@
         if self.args:
             raise LaunchpadScriptFailure("Unhandled arguments %r" % self.args)
 
-        # XXX cprov 2007-03-21: In order to avoid the partial commits inside
-        # BuilddMaster to happen we pass a FakeZtm instance
+        # In order to avoid the partial commits inside BuilddMaster
+        # to happen we pass a FakeZtm instance if dry-run mode is selected.
         class _FakeZTM:
             """A fake transaction manager."""
             def commit(self):

=== modified file 'cronscripts/buildd-retry-depwait.py'
--- cronscripts/buildd-retry-depwait.py	2007-11-22 19:02:24 +0000
+++ cronscripts/buildd-retry-depwait.py	2007-11-23 16:44:08 +0000
@@ -8,13 +8,13 @@
 build-dependencies.
 
 It checks every build in this state, including PPA and PARTNER ones, and
-retry the ones which got their dependencies published after they were tried.
-
-Different than the other buildd-cronscripts, this one it targeted to run via
-cron in parallel with other tasks happen in build farm.
-
-As a optimization, distroseries from the selected distribution which are not
-supported anymore (OBSOLETE status) are skipped from the iteration.
+retries the ones which got their dependencies published after they were tried.
+
+Unlike the other buildd-cronscripts, this one it targeted to run via cron
+in parallel with other tasks happening in build farm.
+
+As an optimization, distroseries from the selected distribution which are not
+supported anymore (OBSOLETE status) are skipped.
 """
 
 __metaclass__ = type

=== modified file 'lib/canonical/buildmaster/master.py'
--- lib/canonical/buildmaster/master.py	2007-11-22 19:00:41 +0000
+++ lib/canonical/buildmaster/master.py	2007-11-23 16:44:08 +0000
@@ -296,7 +296,7 @@
         return logging.getLogger("%s.%s" % (self._logger.name, subname))
 
     def scoreCandidates(self):
-        """Iter over the pending buildqueue entries and re-score it."""
+        """Iterate over the pending buildqueue entries and re-score them."""
         # Get the current build job candidates
         bqset = getUtility(IBuildQueueSet)
         candidates = bqset.calculateCandidates(

=== modified file 'lib/canonical/launchpad/database/build.py'
--- lib/canonical/launchpad/database/build.py	2007-11-22 19:02:24 +0000
+++ lib/canonical/launchpad/database/build.py	2007-11-23 16:44:08 +0000
@@ -249,13 +249,10 @@
         try:
             parsed_deps = apt_pkg.ParseDepends(self.dependencies)
         except (ValueError, TypeError):
-            # XXX cprov 2005-10-18:
-            # We should remove the job if we could not parse its
-            # dependency, but AFAICS, the integrity checks in
-            # uploader component will be in charge of this. In
-            # short I'm confident this piece of code is never
-            # going to be executed
-            return
+            raise AssertionError(
+                "Build dependencies for %s (%s) could not be parsed: '%s'\n"
+                "It indicates that something is wrong in buildd-slaves."
+                % (self.title, self.id, self.depedencies))
 
         missing_deps = []
         for token in parsed_deps:
@@ -263,8 +260,12 @@
             try:
                 name, version, relation = token[0]
             except ValueError:
-                # XXX cprov 2005-10-18: see previous XXX.
-                return
+                raise AssertionError(
+                    "APT is not dealing correctly with a dependency token "
+                    "'%r' from %s (%s) with the following dependencies: %s\n"
+                    "It is expected to be a tuple containing only another "
+                    "tuple with 3 elements  (name, version, relation)."
+                    % (token, self.title, self.id, self.depedencies))
 
             dep_candidate = self.distroarchseries.findDepCandidateByName(name)
             if dep_candidate:

=== modified file 'lib/canonical/launchpad/doc/build.txt'
--- lib/canonical/launchpad/doc/build.txt	2007-11-22 19:02:24 +0000
+++ lib/canonical/launchpad/doc/build.txt	2007-11-23 16:44:08 +0000
@@ -597,6 +597,6 @@
     1005
 
 The 'retryDepWaiting' task is performed periodically via cronjob by
-cronscript/buildd-retry-depwait.py. it can be run in parallel with
+cronscript/buildd-retry-depwait.py. It can be run in parallel with
 other buildd tasks because the procedure is 'atomic' enough, i.e.,
 after the commit the retried jobs are ready to be dispatched.

=== modified file 'lib/canonical/launchpad/interfaces/build.py'
--- lib/canonical/launchpad/interfaces/build.py	2007-11-22 19:02:24 +0000
+++ lib/canonical/launchpad/interfaces/build.py	2007-11-23 16:44:08 +0000
@@ -77,7 +77,7 @@
         """
 
     def updateDependencies():
-        """Update build dependencies line within the targeted context."""
+        """Update the build-dependencies line within the targeted context."""
 
     def __getitem__(name):
         """Mapped to getBinaryPackageRelease."""
@@ -167,7 +167,7 @@
         """Re-process all MANUALDEPWAIT builds for a given IDistroArchSeries.
 
         This method will update all the dependency lines of all MANUALDEPWAIT
-        record in the given architecture and those with all dependencies
+        records in the given architecture and those with all dependencies
         satisfied at this point will be automatically retried and re-scored.
         """
 

=== modified file 'lib/canonical/launchpad/scripts/buildd.py'
--- lib/canonical/launchpad/scripts/buildd.py	2007-11-22 19:02:24 +0000
+++ lib/canonical/launchpad/scripts/buildd.py	2007-11-23 16:44:08 +0000
@@ -28,7 +28,7 @@
             help="Whether or not to commit the transaction.")
 
     def main(self):
-        """Retry all build that do not fit in MANUALDEPWAIT.
+        """Retry all builds that do not fit in MANUALDEPWAIT.
 
         Iterate over all supported series in the given distribution and
         their architectures with existent chroots and update all builds
@@ -60,7 +60,7 @@
 
         # XXX cprov 20071122:  LaunchpadScript should provide some
         # infraestrucutre for dry-run operations and not simply rely
-        # that the transaction would be discarded by the garbage-collector.
+        # on the transaction being discarded by the garbage-collector.
         if not self.options.dryrun:
             self.logger.info('Commiting the transaction.')
             self.txn.commit()

=== modified file 'lib/canonical/launchpad/scripts/ftests/test_buildd_cronscripts.py'
--- lib/canonical/launchpad/scripts/ftests/test_buildd_cronscripts.py	2007-11-22 19:02:24 +0000
+++ lib/canonical/launchpad/scripts/ftests/test_buildd_cronscripts.py	2007-11-23 16:44:08 +0000
@@ -81,7 +81,7 @@
     """Test RetryDepwait buildd script class."""
 
     def setUp(self):
-        """Store the number of pending build present before run the tests."""
+        """Store the number of pending builds present before run the tests."""
         self.number_of_pending_builds = self.getPendingBuilds().count()
 
     def getPendingBuilds(self):
@@ -109,7 +109,7 @@
         """Check the results of a run against pristine sampledata.
 
         Since the only record in MANUALDEPWAIT in sampledata can't be
-        satisfied we expected the number of pending builds to be constant.
+        satisfied we expect the number of pending builds to be constant.
         """
         retry_depwait = self.getRetryDepwait()
         retry_depwait.main()

